pyrkube
~~~~~~~

Maintainer: Joe Black <joeblack949@gmail.com>
Repository: https://www.github.com/joeblackwaslike/pyrkube

This projects wraps the `pykube <https://github.com/kelproject/pykube>`_ project.

Description
-----------

A general purpose wrapper around the ``pykube`` library designed to make things
such as writing configuration templates for containers using Jinja easier with
Kubernetes resources.

It has been open sourced in the case that it might be useful for someone else.
